@@ -1,6 +1,8 @@
 # pylint: disable=unused-argument,invalid-name,line-too-long
 
 
+from typing import Generator
+
 from parse import parse
 from sqlalchemy import text as sql_text
 from sqlalchemy.sql.elements import TextClause
@@ -82,16 +84,16 @@ class PGMaterializedView(ReplaceableEntity):
             f'DROP MATERIALIZED VIEW {self.literal_schema}."{self.signature}" {cascade}'
         )
 
-    def to_sql_statement_create_or_replace(self) -> TextClause:
+    def to_sql_statement_create_or_replace(self) -> Generator[TextClause, None, None]:
         """Generates a SQL "create or replace view" statement"""
         # Remove possible semicolon from definition because we're adding a "WITH DATA" clause
         definition = self.definition.rstrip().rstrip(";")
 
-        return sql_text(
-            f"""
-            DROP MATERIALIZED VIEW IF EXISTS {self.literal_schema}."{self.signature}";
-            CREATE MATERIALIZED VIEW {self.literal_schema}."{self.signature}" AS {definition} WITH {"NO" if not self.with_data else ""} DATA;
-        """
+        yield sql_text(
+            f"""DROP MATERIALIZED VIEW IF EXISTS {self.literal_schema}."{self.signature}"; """
+        )
+        yield sql_text(
+            f"""CREATE MATERIALIZED VIEW {self.literal_schema}."{self.signature}" AS {definition} WITH {"NO" if not self.with_data else ""} DATA"""
         )
 
     def render_self_for_migration(self, omit_definition=False) -> str:
