@@ -2,7 +2,7 @@
 import logging
 from itertools import zip_longest
 from pathlib import Path
-from typing import List, Optional, Set, Type, TypeVar
+from typing import Generator, List, Optional, Set, Type, TypeVar
 
 from alembic.autogenerate import comparators
 from alembic.autogenerate.api import AutogenContext
@@ -86,7 +86,7 @@ class ReplaceableEntity:
         """ Generates a SQL "drop function" statement for PGFunction """
         raise NotImplementedError()
 
-    def to_sql_statement_create_or_replace(self) -> TextClause:
+    def to_sql_statement_create_or_replace(self) -> Generator[TextClause, None, None]:
         """ Generates a SQL "create or replace function" statement for PGFunction """
         raise NotImplementedError()
 
@@ -146,6 +146,8 @@ class ReplaceableEntity:
         object_name = self.signature.split("(")[0].strip().lower().replace("-", "_")
         return f"{schema_name}_{object_name}"
 
+    _version_to_replace: Optional[T] = None  # type: ignore
+
     def get_required_migration_op(
         self: T, sess: Session, dependencies: Optional[List["ReplaceableEntity"]] = None
     ) -> Optional[ReversibleOp]:
@@ -164,6 +166,8 @@ class ReplaceableEntity:
                 return None
 
             if db_def.identity == x.identity:
+                # Cache the currently live copy to render a RevertOp without hitting DB again
+                self._version_to_replace = x
                 return ReplaceOp(self)
 
         return CreateOp(self)
@@ -189,8 +193,6 @@ def register_entities(
 
     **Deprecated Parameters:**
 
-    .. deprecated:: 0.5.1 for removal in 0.6.0
-
     *Configure schema and object inclusion/exclusion with `include_name` and `include_object` in `env.py`. For more information see https://alembic.sqlalchemy.org/en/latest/autogenerate.html#controlling-what-to-be-autogenerated*
 
 
